/**
* @file
* @brief 選択範囲にガイドを作成するスクリプト
* @author dex
* @date $Date: 2010-04-06 18:22:12 +0900 (火, 06  4月 2010) $
* @version $Revision: 143 $
* @note
* - 動作環境: Photoshop CS3/CS4 Windows版
* - encoding: UTF-8N
* - http://dex.qp.land.to/
* - License: MIT license http://sourceforge.jp/projects/opensource/wiki/licenses%2FMIT_license
* - インストール
*   - CS3 以下にコピー
*     - C:\Program Files\Adobe\Adobe Photoshop CS3\プリセット\スクリプト
*   - CS4 以下にコピー
*     - C:\Program Files\Adobe\Adobe Photoshop CS4\Presets\Scripts\
* - ガイドの消去
*   - CS3: メニュー -> ビュー -> ガイドを消去
* - キーボードショートカットの割り当て
*   - メニュー -> 編集 -> キーボードショートカット -> エリア：「アプリケーションメニュー」->アプリケーションメニューコマンド：「ファイル > スクリプト > 対象スクリプト.jsx」 -> ショートカットをクリック -> 適当にキー入力 -> 確定ボタン
* - Changelog
*   - 2010/04/06	リリース
*/

/// main
function main()
{
	var saveUnit = preferences.rulerUnits;
	preferences.rulerUnits = Units.PIXELS;

	var activeDoc = activeDocument;	// アクティブドキュメント
	var activeLay = activeDoc.activeLayer; // アクティブレイヤー

	var x1 = parseInt(activeLay.bounds[0]); // 左上座標
	var y1 = parseInt(activeLay.bounds[1]);
	var x2 = parseInt(activeLay.bounds[2]); // 右下座標
	var y2 = parseInt(activeLay.bounds[3]);
	var width = x2 - x1; // 幅
	var height = y2 - y1; // 高さ

	try{
		// 選択範囲がある
		var boundsObj = activeDoc.selection.bounds;
		x1 = parseInt(boundsObj[0]); // 左上座標
		y1 = parseInt(boundsObj[1]);
		x2 = parseInt(boundsObj[2]); // 右下座標
		y2 = parseInt(boundsObj[3]);
		width = x2 - x1;
		height = y2 - y1;
	}catch(e){
		return;
	}

	// ガイドを追加
	addGuide(x1, 'Vrtc');
	addGuide(x2, 'Vrtc');
	addGuide(y1, 'Hrzn');
	addGuide(y2, 'Hrzn');
}

/**
* ガイド追加
*
* @param	int		offset		ガイドを作成する xおよびy座標
* @param	string	orientation	垂直線:'Vrtc' / 水平線:'Hrzn'
*/
function addGuide(offset, orientation) {
	var id_mk = charIDToTypeID('Mk  ');
	var desc1 = new ActionDescriptor();
	var id_nw = charIDToTypeID('Nw  ');
	var desc2 = new ActionDescriptor();
	var id_pstn = charIDToTypeID('Pstn');
	var id_rlt = charIDToTypeID('#Rlt');
	desc2.putUnitDouble(id_pstn, id_rlt, offset);
	var id_ornt1 = charIDToTypeID('Ornt');
	var id_ornt2 = charIDToTypeID('Ornt');
	var id_type = charIDToTypeID(orientation);
	desc2.putEnumerated(id_ornt1, id_ornt2, id_type);
	var id_gd = charIDToTypeID('Gd  ');
	desc1.putObject(id_nw, id_gd, desc2);
	executeAction(id_mk, desc1, DialogModes.NO);
}

////////////////////////////////////////////////////////////////////////////////
// run
////////////////////////////////////////////////////////////////////////////////
main();
